@@ -23,15 +23,12 @@
 #include "ViewSplitter.h"
 
 // Qt
-#include <QtGui/QKeyEvent>
-
-// KDE
-#include <KDebug>
 
 // Konsole
 #include "ViewContainer.h"
 
-using namespace Konsole;
+using Konsole::ViewSplitter;
+using Konsole::ViewContainer;
 
 ViewSplitter::ViewSplitter(QWidget* parent)
     : QSplitter(parent)
@@ -43,7 +40,7 @@ void ViewSplitter::childEmpty(ViewSplitter* splitter)
 {
     delete splitter;
 
-    if ( count() == 0 )
+    if (count() == 0)
         emit empty(this);
 }
 
@@ -51,18 +48,17 @@ void ViewSplitter::adjustContainerSize(ViewContainer* container , int percentage
 {
     int containerIndex = indexOf(container->containerWidget());
 
-    Q_ASSERT( containerIndex != -1 );
+    Q_ASSERT(containerIndex != -1);
 
     QList<int> containerSizes = sizes();
 
-    int oldSize = containerSizes[containerIndex];
-    int newSize = (int)(oldSize * ( 1.0 + percentage/100.0 ));
+    const int oldSize = containerSizes[containerIndex];
+    const int newSize = (int)(oldSize * (1.0 + percentage / 100.0));
 
-    int perContainerDelta = (count() == 1 ) ? 0 : ( (newSize-oldSize) / (count()-1) ) * (-1);
+    const int perContainerDelta = (count() == 1) ? 0 : ((newSize - oldSize) / (count() - 1)) * (-1);
 
-    for ( int i = 0 ; i < containerSizes.count() ; i++ )
-    {
-        if ( i == containerIndex )
+    for (int i = 0 ; i < containerSizes.count() ; i++) {
+        if (i == containerIndex)
             containerSizes[i] = newSize;
         else
             containerSizes[i] = containerSizes[i] + perContainerDelta;
@@ -77,44 +73,40 @@ ViewSplitter* ViewSplitter::activeSplitter()
 
     ViewSplitter* splitter = 0;
 
-    while ( !splitter && widget )
-    {
-        splitter = dynamic_cast<ViewSplitter*>(widget);
+    while (!splitter && widget) {
+        splitter = qobject_cast<ViewSplitter*>(widget);
         widget = widget->parentWidget();
     }
 
-    Q_ASSERT( splitter );
+    Q_ASSERT(splitter);
     return splitter;
 }
 
-void ViewSplitter::registerContainer( ViewContainer* container )
+void ViewSplitter::registerContainer(ViewContainer* container)
 {
     _containers << container;
-    connect( container , SIGNAL(destroyed(ViewContainer*)) , this , SLOT(containerDestroyed(ViewContainer*)) );
-    connect( container , SIGNAL(empty(ViewContainer*)) , this , SLOT(containerEmpty(ViewContainer*)) );
+    connect(container , SIGNAL(destroyed(ViewContainer*)) , this , SLOT(containerDestroyed(ViewContainer*)));
+    connect(container , SIGNAL(empty(ViewContainer*)) , this , SLOT(containerEmpty(ViewContainer*)));
 }
 
-void ViewSplitter::unregisterContainer( ViewContainer* container )
+void ViewSplitter::unregisterContainer(ViewContainer* container)
 {
     _containers.removeAll(container);
-    disconnect( container , 0 , this , 0 );
+    disconnect(container , 0 , this , 0);
 }
 
 void ViewSplitter::updateSizes()
 {
     int space;
 
-    if ( orientation() == Qt::Horizontal )
-    {
+    if (orientation() == Qt::Horizontal) {
         space = width() / count();
-    }
-    else
-    {
+    } else {
         space = height() / count();
     }
 
     QList<int> widgetSizes;
-    for (int i=0;i<count();i++)
+    for (int i = 0; i < count(); i++)
         widgetSizes << space;
 
     setSizes(widgetSizes);
@@ -129,76 +121,68 @@ bool ViewSplitter::recursiveSplitting() const
     return _recursiveSplitting;
 }
 
-void ViewSplitter::removeContainer( ViewContainer* container )
+void ViewSplitter::removeContainer(ViewContainer* container)
 {
-    Q_ASSERT( containers().contains(container) );
+    Q_ASSERT(containers().contains(container));
 
     unregisterContainer(container);
 }
 
-void ViewSplitter::addContainer( ViewContainer* container , 
-                                 Qt::Orientation containerOrientation )
+void ViewSplitter::addContainer(ViewContainer* container ,
+                                Qt::Orientation containerOrientation)
 {
-   ViewSplitter* splitter = activeSplitter();   
+    ViewSplitter* splitter = activeSplitter();
 
-    if ( splitter->count() < 2 || 
-         containerOrientation == splitter->orientation() ||
-         !_recursiveSplitting )
-    {
-        splitter->registerContainer(container); 
+    if (splitter->count() < 2 ||
+            containerOrientation == splitter->orientation() ||
+            !_recursiveSplitting) {
+        splitter->registerContainer(container);
         splitter->addWidget(container->containerWidget());
 
-        if ( splitter->orientation() != containerOrientation )
-            splitter->setOrientation( containerOrientation );
+        if (splitter->orientation() != containerOrientation)
+            splitter->setOrientation(containerOrientation);
 
         splitter->updateSizes();
-    }
-    else
-    {
+    } else {
         ViewSplitter* newSplitter = new ViewSplitter(this);
-        connect( newSplitter , SIGNAL(empty(ViewSplitter*)) , splitter , SLOT(childEmpty(ViewSplitter*)) );
+        connect(newSplitter , SIGNAL(empty(ViewSplitter*)) , splitter , SLOT(childEmpty(ViewSplitter*)));
 
         ViewContainer* oldContainer = splitter->activeContainer();
-        int oldContainerIndex = splitter->indexOf(oldContainer->containerWidget());
+        const int oldContainerIndex = splitter->indexOf(oldContainer->containerWidget());
 
-        splitter->unregisterContainer(oldContainer);   
+        splitter->unregisterContainer(oldContainer);
 
         newSplitter->registerContainer(oldContainer);
         newSplitter->registerContainer(container);
 
         newSplitter->addWidget(oldContainer->containerWidget());
         newSplitter->addWidget(container->containerWidget());
-        newSplitter->setOrientation(containerOrientation); 
+        newSplitter->setOrientation(containerOrientation);
         newSplitter->updateSizes();
         newSplitter->show();
 
-        splitter->insertWidget(oldContainerIndex,newSplitter);
+        splitter->insertWidget(oldContainerIndex, newSplitter);
     }
-
 }
 
-void ViewSplitter::containerEmpty(ViewContainer* /*object*/)
+void ViewSplitter::containerEmpty(ViewContainer* /*container*/)
 {
-    QListIterator<ViewContainer*> containerIter(_containers);
-
     int children = 0;
-    while (containerIter.hasNext())
-    {
-        children += containerIter.next()->views().count();
+    foreach(ViewContainer* container, _containers) {
+        children += container->views().count();
     }
 
-    if ( children == 0 )
-        emit allContainersEmpty(); 
+    if (children == 0)
+        emit allContainersEmpty();
 }
 
-void ViewSplitter::containerDestroyed(ViewContainer* object)
+void ViewSplitter::containerDestroyed(ViewContainer* container)
 {
-    Q_ASSERT( _containers.contains(object) );
+    Q_ASSERT(_containers.contains(container));
 
-    _containers.removeAll(object);
+    _containers.removeAll(container);
 
-    if ( count() == 0 )
-    {
+    if (count() == 0) {
         emit empty(this);
     }
 }
@@ -209,79 +193,68 @@ void ViewSplitter::activateNextContainer()
 
     int index = _containers.indexOf(active);
 
-    if ( index == -1 )
+    if (index == -1)
         return;
 
-    if ( index == _containers.count() -1 )
+    if (index == _containers.count() - 1)
         index = 0;
     else
         index++;
 
-    setActiveContainer( _containers.at(index) );
+    setActiveContainer(_containers.at(index));
 }
 
-void ViewSplitter::activatePreviousContainer() 
+void ViewSplitter::activatePreviousContainer()
 {
     ViewContainer* active = activeContainer();
 
     int index = _containers.indexOf(active);
 
-    if ( index == 0 )
-       index = _containers.count() - 1;
+    if (index == 0)
+        index = _containers.count() - 1;
     else
-       index--;
+        index--;
 
-    setActiveContainer( _containers.at(index) ); 
+    setActiveContainer(_containers.at(index));
 }
 
-
 void ViewSplitter::setActiveContainer(ViewContainer* container)
 {
     QWidget* activeView = container->activeView();
 
-    if ( activeView )
-        activeView->setFocus( Qt::OtherFocusReason );
+    if (activeView)
+        activeView->setFocus(Qt::OtherFocusReason);
 }
 
 ViewContainer* ViewSplitter::activeContainer() const
 {
-   if ( QWidget* focusW = focusWidget() )
-   {
+    if (QWidget* focusW = focusWidget()) {
         ViewContainer* focusContainer = 0;
 
-        while ( focusW != 0 )
-        {
-            QListIterator<ViewContainer*> containerIter(_containers);
-            while (containerIter.hasNext())
-            {
-                ViewContainer* nextContainer = containerIter.next();
-
-                if (nextContainer->containerWidget() == focusW)
-                {
-                    focusContainer = nextContainer;
+        while (focusW != 0) {
+            foreach(ViewContainer* container, _containers) {
+                if (container->containerWidget() == focusW) {
+                    focusContainer = container;
                     break;
                 }
             }
             focusW = focusW->parentWidget();
         }
 
-        if ( focusContainer )
+        if (focusContainer)
             return focusContainer;
-   }
+    }
 
-   QList<ViewSplitter*> splitters = findChildren<ViewSplitter*>();
+    QList<ViewSplitter*> splitters = findChildren<ViewSplitter*>();
 
-   if (splitters.count() > 0)
-   {
+    if (splitters.count() > 0) {
         return splitters.last()->activeContainer();
-   }
-   else
-   {
-       if ( _containers.count() > 0 )
-           return _containers.last();
-       else
-           return 0;
-   }
+    } else {
+        if (_containers.count() > 0)
+            return _containers.last();
+        else
+            return 0;
+    }
 }
 
 #include "ViewSplitter.moc"
